package com.esignlive.guidance.forum;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import java.util.zip.ZipOutputStream;

import org.apache.commons.io.IOUtils;

import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;

public class _23_05_09_download_document_with_evidence_summary {
	
    public static void main(String[] args) throws IOException {
    	String API_KEY = "your_api_key";
		String API_URL = "https://sandbox.esignlive.com/api";
		PackageId packageId = new PackageId("c1cQItVo-DG3xuLBgUKCqBBMAC0=");
		String outputPath = "...\\"+packageId.getId()+".zip";
		EslClient eslClient = new EslClient(API_KEY, API_URL);
    	
        byte[] zipByteArray = eslClient.downloadZippedDocuments(packageId); 
        byte[] pdf1 = eslClient.downloadEvidenceSummary(packageId); 

        Map<String, byte[]> extractedPDFs = extractPDFsFromZipByteArray(zipByteArray);
        extractedPDFs.put("Evidence Summary.pdf",pdf1);
        
        byte[] newZipByteArray = createZipByteArrayFromPDFs(extractedPDFs);

        try (FileOutputStream fos = new FileOutputStream(outputPath)) {
            fos.write(newZipByteArray);
        }
    }

    public static Map<String, byte[]> extractPDFsFromZipByteArray(byte[] zipByteArray) throws IOException {
        Map<String, byte[]> pdfs = new LinkedHashMap<>();
        try (ByteArrayInputStream bais = new ByteArrayInputStream(zipByteArray);
             ZipInputStream zis = new ZipInputStream(bais)) {

            ZipEntry entry;
            while ((entry = zis.getNextEntry()) != null) {
                if (entry.getName().toLowerCase().endsWith(".pdf")) {
                    ByteArrayOutputStream baos = new ByteArrayOutputStream();
                    IOUtils.copy(zis, baos);
                    pdfs.put(entry.getName(),baos.toByteArray());
                }
                zis.closeEntry();
            }
        }
        return pdfs;
    }

    public static byte[] createZipByteArrayFromPDFs(Map<String, byte[]> pdfs) throws IOException {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try (ZipOutputStream zos = new ZipOutputStream(baos)) {
        	for(Map.Entry<String, byte[]> entry: pdfs.entrySet()) {
        		  ZipEntry zipEntry = new ZipEntry(entry.getKey());
                  zos.putNextEntry(zipEntry);
                  ByteArrayInputStream bais = new ByteArrayInputStream(entry.getValue());
                  IOUtils.copy(bais, zos);
                  zos.closeEntry();
        	}
        }
        return baos.toByteArray();
    }
}
	
